<?php

/**
 * Gestion de l'action remettant à zéro l'ordre des albums liés à un objet
 *
 * @note
 * On utilise volontairement des signatures génériques
 * en prévision d'une éventuelle intégration future dans le core,
 * ainsi à ce moment on n'aura pas à trop changer les appels.
 * Donc pas de table spip_albums_liens en dur, etc.
 *
 * @plugin     Albums
 * @copyright  2012-2022
 * @author     Tcharlss
 * @licence    GNU/GPL
 * @package    SPIP\Albums\Action
 */

// Sécurité
if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

/**
 * Remettre à zéro l'ordre des albums liés à un objet
 *
 * @param string|null $arg
 *     Fournit les arguments de la fonction desordonner_liens_albums, séparés par des tirets.
 *     Ex. : `album-article-10-rang_lien`
 * @return void
 */
function action_desordonner_liens_albums_dist(?string $arg = null) {
	include_spip('base/objets');
	include_spip('action/editer_liens');

	// Si $arg est null, le récupérer dans le POST
	if (is_null($arg)) {
		$securiser_action = charger_fonction('securiser_action', 'inc');
		$arg = $securiser_action();
	}
	$data = explode('-', $arg);
	[$objet, $objet_lie, $id_objet_lie, $champ_rang] = $data;

	// Objet source possédant la table de liens et éventuellement la colonne portant le rang
	$objet = objet_type($objet);
	$champ_rang = $champ_rang ?: '';

	// objet lié
	$objet_lie = objet_type($objet_lie);
	$id_objet_lie = intval($id_objet_lie);

	// Vérifs : il faut avoir le droit de modifier l'objet lié
	if (
		!$objet
		or !$objet_lie
		or !$id_objet_lie
		or !objet_associable($objet)
	) {
		spip_log("desordonner_liens_albums / arguments manquants ou incompris : $arg", 'albums');
	} elseif (!autoriser('modifier', $objet_lie, $id_objet_lie)) {
		spip_log("desordonner_liens_albums / modifier $objet_lie $id_objet_lie interdit : $arg", 'albums');
	} else {
		desordonner_liens_albums($objet, $objet_lie, $id_objet_lie, $champ_rang);
	}
}

/**
 * Remettre à zéro l'ordre des albums liés à un objet
 *
 * @param string $objet
 *     Type d'objet à dissocier (celui qui posséde la table de liens, les albums quoi)
 * @param string $objet_lie
 *     Objet duquel dissocier
 * @param  $id_objet_lie
 *     Numéro de l'objet duquel dissocier
 * @return void
 */
function desordonner_liens_albums(string $objet, string $objet_lie, int $id_objet_lie, ?string $champ_rang): void {
	include_spip('action/editer_liens');
	// Colonne pour le rang sur table spip_xxx_liens
	// Si pas donné, on prend en dur pour l'instant. Pourrait-être donné plus tard par objet_associable() ?
	$champ_rang = ($champ_rang ?: 'rang_lien');
	objet_qualifier_liens(
		[$objet => '*'],
		[$objet_lie => $id_objet_lie],
		[$champ_rang => 0]
	);
}
