/**
 * Gestion du tri des listes d'albums et de leur enregistrement.
 *
 * Tout est déclenché à partir d'attributs data.
 *
 * Markup nécessaire :
 *
 * [data-ordonnable][data-type][data-lien] : conteneur général avec le type d'objet ordonnable et l'identifiant de l'objet lié
 *   .sortable                             : conteneur direct des items à ordonner
 *      [data-item-ordonnable][data-id]    : chaque item à ordonner
 *        [data-move][data-rang]           : le bouton qui déclenche le glisser-déposer
 *
 * Nb : fonctionnalité qui pourrait potentiellement être dans le core,
 * donc on fait ça de façon générique en vue d'une intégration ultérieure.
 */
function albums_ordonner() {

	const selecteurs = {
		conteneur:      "[data-ordonnable][data-type][data-lien]",
		item:           "[data-item-ordonnable]",
		sortable:       "> .sortable",
		btn_move:       "[data-move][data-rang]",
		btn_reordonner: ".tout-desordonner",
	}

	const classes = {
		ghost:  "deplacer-ghost",
		moving: "deplacer-en-mouvement",
	}

	if (typeof Sortable === 'function') {
		$(selecteurs.conteneur).find(selecteurs.sortable).each(function () {
			// détruire / recréer le sortable à chaque appel ajax
			if (Sortable.get(this)) {
				Sortable.get(this).destroy();
			}
			// pas de tri possible s'il n'y a qu'un seul élément.
			if ($(this).find(selecteurs.item).length < 2) {
				$(this).find(selecteurs.btn_move).hide();
				$(this).parent().find(selecteurs.btn_reordonner).hide();
				return true; // continue
			} else {
				$(this).find(selecteurs.btn_move).show();
				$(this).find(selecteurs.item).addClass('box_album_ordonnable');
			}
			new Sortable(this, {
				/*direction: 'vertical',*/
				swapThreshold: .8,
				ghostClass: classes.ghost,
				onStart: function(event) {
					$(event.item).addClass(classes.moving);
				},
				onEnd: function(event) {
					$(event.item).removeClass(classes.moving);
				},
				onUpdate: function (event) {
					const ordre = this.toArray();
					const $items = $(event.from);
					const $item = $(event.item);
					const $conteneur = $items.parents(selecteurs.conteneur);

					// Le conteneur indique aux moyens d'attributs data : le type d'objet ordonnable, l'objet lié, et éventuellement le champ de la table de liens
					const objet_source = $conteneur.data("type");
					const [objet_lie, id_objet_lie] = $conteneur.data("lien").split("/");
					const champ  = $conteneur.data("champ") || null;
					const action = spipConfig.url_action_ordonner_liens_albums;
					const params = {
						objet_source: objet_source,
						objet_lie:    objet_lie,
						id_objet_lie: id_objet_lie,
						ordre:        ordre,
						champ:        champ,
					};

					$item.animateLoading();

					$.post({
						url: action,
						data: params,
						dataType: 'json',
						cache: false,
					}).done(function(data) {

						const couleur_origine = $item.css('background-color');
						const couleur_erreur = $("<div class='remove'></div>").css('background-color');
						const couleur_succes = $("<div class='append'></div>").css('background-color');
						$item.endLoading(true);

						if (data.errors.length) {
							$item.css({backgroundColor: couleur_erreur}).animate({backgroundColor: couleur_origine}, 'normal', () => {
								$item.css({backgroundColor: ''});
							});
						} else {
							$item.css({backgroundColor: couleur_succes}).animate({backgroundColor: couleur_origine}, 'normal', () => {
								$item.css({backgroundColor: ''});
							});
							$items.parent().find(selecteurs.btn_reordonner).show();
						}
					})
					.fail(function() {
						// todo
					});
				}
			});

			// bouton "désordonner"
			if ($(this).parent().find(selecteurs.btn_move).data("rang") !== 0) {
				$(this).parent().find(selecteurs.btn_reordonner).show();
			} else {
				$(this).parent().find(selecteurs.btn_reordonner).hide();
			}
		});
	}
}

/* Initialisation et relance en cas de chargement ajax */
if (window.jQuery) {
	jQuery(function($){
		if (!$.js_albums_ordonner_charge) {
			$.js_albums_ordonner_charge = true;
			if (typeof Sortable === "undefined") {
				jQuery.getScript(spipConfig.url_script_sortable).done(albums_ordonner);
			} else {
				albums_ordonner();
			}
			onAjaxLoad(albums_ordonner);
		}
	});
}